@@ -408,10 +408,10 @@ sub update {
     $this->_put($uri, $xml);
 }
 
-#### update to allow creating master records
 sub add {
     my $this = shift();
     my($master, $realm, $worldId, $user, %data) = @_;
+    my $admin = $this->admin();
 
     die "add invoked on 'world'" if defined $realm && $realm eq "world";
     $this->_logTorusOp("add", master=>$master, realm=>$realm, worldId=>$worldId, user=>$user);
@@ -421,10 +421,18 @@ sub add {
     }
 
     my %extra = ();
-    if ($this->admin()->conf("constrainIdentity")) {
+    if ($admin->conf("constrainIdentity")) {
 	%extra = (identityId => $user->field("identityId"));
     }
 
+    my @fields = $admin->fieldsWithDefaultValues();
+    foreach my $field (@fields) {
+	if (!defined $data{$field}) {
+	    $extra{$field} = $admin->conf("field.$field.defaultValue");
+	    warn "set default value $field='" . $extra{$field} . "'";
+	}
+    }
+
     $data{worldId} = $worldId if defined $worldId;
     my($uri, $xml);
     if ($master) {
